==> haskell-aws-0.22-274-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.22
visibility:           public
id:                   aws-0.22-7TbqdyheVmC2smf7bqjRNq
key:                  aws-0.22-7TbqdyheVmC2smf7bqjRNq
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  88c67852377118f4547e2a9888b44ad0
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-8.10.4/site-local/aws-0.22
library-dirs:         /usr/lib/ghc-8.10.4/site-local/aws-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/aws-0.22
hs-libraries:         HSaws-0.22-7TbqdyheVmC2smf7bqjRNq
depends:
    aeson-1.5.6.0-APBE3PUwRlP3dNFj9eIcL4
    attoparsec-0.14.1-C6wGreXaJC9Hw3F0wMqT0I base-4.14.1.0
    base16-bytestring-1.0.1.0-80192mp86Px9nsPUc5UNoi
    base64-bytestring-1.2.0.1-CAhkLoCyIrTKD1yj3isejI
    blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
    byteable-0.1.1-2tCrGdFfJISCmoPhB610i6 bytestring-0.10.12.0
    case-insensitive-1.2.1.0-3NIW57P40JN584hTPPyqOm
    cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    conduit-1.3.4.1-2UBFVQ0sYph5gpPD4o0VhI
    conduit-extra-1.3.5-LL06GWvywBRGCKw4LD3p7c containers-0.6.2.1
    cryptonite-0.29-cZhf4F0aLI1tXiPEdH3tE
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    http-client-tls-0.3.5.3-5dWa1KS6P5X5YkgqqYBkqx
    http-conduit-2.3.8-3MB1njQamNGITHABabZdgi
    http-types-0.12.3-BYUAs1lHLtj2I55gruLmDn
    lifted-base-0.2.3.12-1A0CVWZ5D6fKp9q61vGKi0
    memory-0.16.0-FcR25XxjAGsCy9iFRDcpya
    monad-control-1.0.2.3-Sehdjv5bTLCM18tS2ckf4 mtl-2.2.2
    network-3.1.2.1-DsZbGjsE7U23ms8WBrhjnk
    network-bsd-2.8.1.0-5JLkm4wj7dKFzvmvTN57Xg
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    resourcet-1.2.4.2-IH7ySIJaTCj8sH8F5bjoZO
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    scientific-0.3.7.0-KCh24HsT89PHzfe66i6CI6
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-HPNAhY9eekUIwMlQFAvZlw
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.3.0-FUD0lZOETAI870JKqcsC0A
    xml-conduit-1.9.1.1-Kp9EpO3JnGQK7jMNh9Z4PA

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.22-280-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.22
visibility:           public
id:                   aws-0.22-CEPA4ErJPZeBV5kYhNPLV9
key:                  aws-0.22-CEPA4ErJPZeBV5kYhNPLV9
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  3e3ae26b38c38fcd5c6289555752dc89
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-8.10.5/site-local/aws-0.22
library-dirs:         /usr/lib/ghc-8.10.5/site-local/aws-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/aws-0.22
hs-libraries:         HSaws-0.22-CEPA4ErJPZeBV5kYhNPLV9
depends:
    aeson-1.5.6.0-6uunGgFAYkLL5zoDUTK2GY
    attoparsec-0.14.1-qO4BENHL0SHN8QdgrNcG6 base-4.14.2.0
    base16-bytestring-1.0.1.0-1hJhTC4ftcxEBVwj2vhRFK
    base64-bytestring-1.2.0.1-6PvrigrzgN5CFxMJsxx0QP
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
    byteable-0.1.1-Gf4TH6XbSdI4yHpNVK8xgD bytestring-0.10.12.0
    case-insensitive-1.2.1.0-JPdBXBeCcNF9RB4NR2tt4M
    cereal-0.5.8.1-4r85zOZIbEW4fo8WFnBuTl
    conduit-1.3.4.1-CU2UV8EGOC0G969ooXKq7I
    conduit-extra-1.3.5-BP68kZVTyGvWhp3lr4D8M containers-0.6.4.1
    cryptonite-0.29-3JSUkOlGQg3XBOKlyqMAW
    data-default-0.7.1.1-1PvF2urvLxF7Pa94frLNmw directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    http-client-tls-0.3.5.3-7HFlEpdnloR2CYJZdjZOe3
    http-conduit-2.3.8-6gWnW6oVyps6j4rhb4ZgPw
    http-types-0.12.3-19oZT8Fua6FHdxhPU1oghZ
    lifted-base-0.2.3.12-Hz80hBEOa9WKf3k5vx9zFo
    memory-0.16.0-E1gXzMJzgEcJ8QhI9dLs6S
    monad-control-1.0.2.3-2cyZy9k7m5IA7Z3KwFJTMb mtl-2.2.2
    network-3.1.2.2-25lMYs5jWh9BSaCkMt8wPK
    network-bsd-2.8.1.0-1zQs5Eg2Zqq8t5RFzvbQVZ
    old-locale-1.0.0.7-L6Wsx5CTYHFJNpULKIS1yv
    resourcet-1.2.4.2-Gfu0kyxxOMA2Bc8Qssjz0Z
    safe-0.3.19-DlKvqLTtraZKItu5PR3KBM
    scientific-0.3.7.0-9YboVbL14mb3RAuy75saJh
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-1OFWlQlrCvvLaIazZ0Uw3i
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du
    vector-0.12.3.0-EcRb4NXFUGH91vV3xG3jJs
    xml-conduit-1.9.1.1-IpoB64Y6FcV4ZJQQksKziX

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
